@@ -4,7 +4,7 @@ function(temps, n0, Nn, Ah, An, ff, ae,
          hr, outfile=NULL, plot=TRUE) {
     UseMethod("simqOTOR")
 } #
-### 2016.05.22.
+### 2019.12.03.
 simqOTOR.default <- 
 function(temps, n0, Nn, Ah, An, ff, ae,
          hr, outfile=NULL, plot=TRUE) {
@@ -61,6 +61,9 @@ function(temps, n0, Nn, Ah, An, ff, ae,
     sp <- try(calShape(tout, yout), silent=TRUE)
     ###
     if (plot==TRUE)  {
+        opar <- par("mfrow", "mar")
+        on.exit(par(opar))
+
         layout(cbind(c(rep(1,13), 2, rep(3,6)), 
                      c(rep(1,13), 2, rep(3,6))))
         ###
@@ -101,13 +104,11 @@ function(temps, n0, Nn, Ah, An, ff, ae,
         plot(c(0,0), type="n", xaxt="n", yaxt="n", xlab="n", ylab="")
         ###
         ### The third plot.
-        par(mar = c(5.1, 5.1, 0, 1.1))
+        par(mar=c(5.1, 5.1, 0, 1.1))
         plot(tout, res$vecy, type="l", xlab = "Temperature(K)", 
              ylab="Concentration", las=0, lab=c(7,7,9), xaxs="r", yaxs="i",
              ylim=c(-0.1*n0, 1.1*n0), col="grey", lwd=5, cex.lab=2.0, cex.axis=1.5)
-        box(lwd=2L) 
-        par(mar=c(5,4,4,2)+0.1)
-        layout(1L)
+        box(lwd=2L)
     } # end if.
     ###
     if (class(sp)=="try-error")  sp <- NULL
